InputKind

Enum InputKind 

pub enum InputKind {
Show 30 variants Pdf, Doc, Docx, Ppt, Pptx, Html, Asciidoc, Markdown, Csv, Xlsx, Xls, Odt, Ods, Odp, Epub, Email, Image, XmlUspto, XmlJats, XmlXbrl, XmlDoclang, MetsGbs, JsonDocling, Dclx, Audio, Video, Vtt, Boxnote, Latex, Text,
}

Variants



Pdf



Doc



Docx



Ppt



Pptx



Html



Asciidoc



Markdown



Csv



Xlsx



Xls



Odt



Ods



Odp



Epub



Email



Image



XmlUspto



XmlJats



XmlXbrl



XmlDoclang



MetsGbs



JsonDocling



Dclx



Audio



Video



Vtt



Boxnote



Latex



Text

Implementations

Source

impl InputKind

pub fn from_path(path: &Path) -> Option<Self>

pub fn from_filename_and_media_type( filename: &str, media_type: Option<&str>, ) -> Option<Self>

pub fn requires_explicit_override( filename: &str, media_type: Option<&str>, ) -> bool

pub fn media_type(self) -> &'static str

pub fn canonical_media_type( self, filename: &str, media_type: Option<&str>, ) -> &'static str

pub fn default_extension(self) -> &'static str

pub fn default_extension_for_media_type( self, media_type: Option<&str>, ) -> &'static str

pub fn reading_label(self) -> &'static str

pub fn from_formats_value(self) -> &'static str

pub fn uses_generic_convert_options(self) -> bool

pub fn supports_vlm(self) -> bool