pub struct DocumentConverter { /* private fields */ }Implementations
Sourceimpl DocumentConverter
impl DocumentConverter
pub fn calculate_output_path( output_dir: &Path, filename: &str, output_format: OutputFormat, ) -> PathBuf
Sourceimpl DocumentConverter
impl DocumentConverter
pub async fn convert_source_to_file_async( &self, url: &str, filename: impl Into<String>, input_kind: InputKind, output_formats: Vec<OutputFormat>, options: &RemoteConvertOptions, output_dir: PathBuf, selected_output: OutputFormat, overwrite: bool, ) -> Result<ConvertedFile>
pub async fn convert_source_to_file_async_with_docling_progress<F, Fut>( &self, url: &str, filename: impl Into<String>, input_kind: InputKind, output_formats: Vec<OutputFormat>, options: &RemoteConvertOptions, output_dir: PathBuf, selected_output: OutputFormat, overwrite: bool, on_status: F, ) -> Result<ConvertedFile>
pub fn document_from_task_result( input: &InputDocument, task_result: DoclingTaskResult, ) -> Result<ConvertedDocument>
Sourceimpl DocumentConverter
impl DocumentConverter
pub fn new(docling_client: DoclingClient) -> Self
Sourcepub async fn submit_async(&self, request: &ConvertRequest) -> Result<String>
pub async fn submit_async(&self, request: &ConvertRequest) -> Result<String>
Submit a whole-document asynchronous conversion and return only the remote task id. The caller owns polling and result fetching, which makes the conversion resumable across restarts.
pub async fn convert( &self, request: ConvertRequest, ) -> Result<ConvertedDocument>
pub async fn convert_async( &self, request: ConvertRequest, ) -> Result<ConvertedDocument>
pub async fn convert_with_progress<F, Fut>( &self, request: ConvertRequest, on_progress: F, ) -> Result<ConvertedDocument>
pub async fn convert_async_with_progress<F, Fut>( &self, request: ConvertRequest, on_progress: F, ) -> Result<ConvertedDocument>
pub async fn convert_async_with_docling_progress<F, Fut>( &self, request: ConvertRequest, on_status: F, ) -> Result<ConvertedDocument>
pub async fn convert_to_file( &self, request: FileConvertRequest, ) -> Result<ConvertedFile>
pub async fn convert_to_file_with_progress<F, Fut>( &self, request: FileConvertRequest, on_progress: F, ) -> Result<ConvertedFile>
pub async fn convert_to_file_async( &self, request: FileConvertRequest, ) -> Result<ConvertedFile>
pub async fn convert_to_file_async_with_progress<F, Fut>( &self, request: FileConvertRequest, on_progress: F, ) -> Result<ConvertedFile>
pub async fn convert_to_file_async_with_docling_progress<F, Fut>( &self, request: FileConvertRequest, on_status: F, ) -> Result<ConvertedFile>